elemsToExt: Convert inits elements to a parameter data.frame

elemsToExtR Documentation

Convert inits elements to a parameter data.frame

Description

Convert inits elements to a parameter data.frame

Usage

elemsToExt(elements)

Arguments

elements

The elements object produced by 'NMreadInits()'.

Details

Function name changed from initsToExt which was misleading. It is not a reference to the initstab, but actually the elements object returned by NMreadInits. The elements object is more detailed as it contains information about where information is found in control stream lines. The 'ext' object is a parameter 'data.frame', same format as returned by 'NMdata::NMreadExt()'.


NMdata documentation built on June 17, 2026, 9:06 a.m.