filePathSimple: Clean and standardize file system paths

View source: R/filePathSimple.R

filePathSimpleR Documentation

Clean and standardize file system paths

Description

Use this to tidy up paths. Combines pieces of a path like file.path(). The function is intended to return a canonical path format, i.e. paths that can be compared by simple string comparison. Redundant /'s removed. normalizePath is used to possibly shorten path.

Usage

filePathSimple(...)

Arguments

...

additional arguments passed to file.path(). If empty (NULL or zero length vectors) are included they will be dropped. This can be convenient for programming.

Value

A (character) file path


NMdata documentation built on March 19, 2026, 5:08 p.m.