itriag: Row numbers of elements in a triangular representation of a...

View source: R/NMreadInits.R

itriagR Documentation

Row numbers of elements in a triangular representation of a symmetric matrix

Description

Row numbers of elements in a triangular representation of a symmetric matrix

Usage

itriag(blocksize, istart = 1, diag = "lower")

NMdata documentation built on June 17, 2026, 9:06 a.m.