splitFields: splitFields splits the fields format string into the...

splitFieldsR Documentation

splitFields splits the fields format string into the splitters and the variable names. NB, this is interpreting the user-provided fields, it is not looking at control stream text,

Description

splitFields splits the fields format string into the splitters and the variable names. NB, this is interpreting the user-provided fields, it is not looking at control stream text,

Usage

splitFields(format, spaces.split = FALSE)

NMdata documentation built on March 19, 2026, 5:08 p.m.