dcastSe: A standard-evaluation interface to 'data.table::dcast()

View source: R/dcastSe.R

dcastSeR Documentation

A standard-evaluation interface to 'data.table::dcast()

Description

data.table's dcast() transforms from long to wide format. It lacks a standard-evalutation interface for programming, and dcastSe() is an attempt to fill that gap, still using data.table::dcast() to perform the operation.

Usage

dcastSe(data, l, r, as.fun, ...)

Arguments

data

data set to transpose (widen)

l

left-hand side variables as character vector. Result will be long/vertical in these variables.

r

left-hand side variables as character vector. Result will be wide in these variables.

as.fun

An optional function to convert results with. If 'data' is a 'data.table', the default is to return a 'data.table', and if not the default is to return a 'data.frame'.

...

Additional arguments passed to 'data.table::dcast()'.

Details

Only two of l, r, and value.var are needed (see ?data.table::dcast for value.var), and the others will be derived. However, if value.var is a function, both l and r are needed.

Value

a data.table


NMdata documentation built on March 19, 2026, 5:08 p.m.