| elemsToExt | R Documentation |
Convert inits elements to a parameter data.frame
elemsToExt(elements)
elements |
The elements object produced by 'NMreadInits()'. |
Function name changed from initsToExt which was misleading. It is not a reference to the initstab, but actually the elements object returned by NMreadInits. The elements object is more detailed as it contains information about where information is found in control stream lines. The 'ext' object is a parameter 'data.frame', same format as returned by 'NMdata::NMreadExt()'.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.