itriag: Row numbers of elements in a triangular representation of a...

View source: R/NMreadInits.R

itriagR Documentation

Row numbers of elements in a triangular representation of a symmetric matrix

Description

Row numbers of elements in a triangular representation of a symmetric matrix

Usage

itriag(blocksize, istart = 1, diag = "lower")

NMdata documentation built on March 19, 2026, 5:08 p.m.